@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
 from .sale import *
@@ -16,4 +16,8 @@ def register():
         Purchase,
         ShipmentIn,
         Template,
+        Product,
         module='sale_supply', type_='model')
+    Pool.register(
+        HandlePurchaseCancellationException,
+        module='sale_supply', type_='wizard')
